{% extends "base.html" %}

{# append our extra stylesheets#}
{% block styles %}
  {{ super() }}
  <link rel="stylesheet" href="{{ 'assets/stylesheets/extra.css' | url }}">
{% endblock %}

{% block footer %}
  <footer class="md-footer">
    <div class="md-footer-meta__inner md-grid">

      <div class="md-copyright">
        Made with 
        <a href="https://squidfunk.github.io/mkdocs-material/" target="_blank" rel="noopener">
          Material for MkDocs
        </a>
        <br>
        <br>
        <img src="{{ 'assets/images/ogl.png' |url }}" >
        All content is available under the 
        <a
            href="https://www.nationalarchives.gov.uk/doc/open-government-licence/version/3/"
            target="_blank" rel="noopener"
        >
            Open Government Licence v3.0</a>
        , except where otherwise stated
      </div>

      <div class="md-copyright">
        <a 
          href="https://www.nationalarchives.gov.uk/information-management/re-using-public-sector-information/uk-government-licensing-framework/crown-copyright/"
          target="_blank" rel="noopener">
          <img src="{{ 'assets/images/govuk-crest-2x.png' | url }}" width=120px height=100px;>
          <br>
          © Crown copyright
        </a>
      </div>

    </div>
  </footer>
{% endblock %}
