:root > * {
  --md-primary-fg-color: #000000;
  --md-default-fg-color--light: #000000;
  --md-typeset-a-color: #1d70b8;
  --md-accent-fg-color: 	#003078;
  --md-footer-bg-color:    #f3f2f1;
  --md-footer-bg-color--dark:    #f3f2f1;
  --md-footer-fg-color: #505a5f;
  --md-footer-fg-color--light: #505a5f;
  --md-footer-fg-color--lighter: #505a5f;
}

.md-typeset h1 {
  font-size: 48px;
  font-weight: 700;
}

.md-typeset h2 {
  font-weight: 700;
}

.md-typeset h3 {
  font-weight: 700;
}

.md-typeset a {
  text-decoration: underline;
  text-underline-offset: 2px;
}

.md-header{
  box-shadow: none;
}

.md-header__title{
  font-size: 25px;
}

.md-header__topic:first-child{
  font-weight: 400;
}

.md-footer{
  border-top: 1px solid;
  border-color: #b1b4b6;
}

.md-copyright{
  font-size: 15px;
  color:#000000;
}

.md-copyright a {
  text-decoration: underline;
  text-underline-offset: 2px;
}

/* Configures the navigation bar */
.md-nav {
  font-size: 15px;
  line-height: 1.5;
}

.md-nav--primary {
  color: #1d70b8;
}

.md-nav__link:hover {
  text-decoration: underline;
  text-decoration-thickness: 3px;
  text-underline-offset: 2px;
}

.md-nav__item--active .md-nav__item--active {
  font-weight: 700; 
  margin-left: 10px; 
  padding-left: 3px;
  border-left: 3px solid;
  border-left-color:   #1d70b8;
}

.md-nav--secondary .md-nav__link--active {
  /* font-weight: 700;  */
  padding-left: 3px;
  border-left: 3px solid;
  border-left-color:   #1d70b8;
}

/* Configures the tabs below the header */
.md-tabs {
  color: #1d70b8;
  background-color: #f8f8f8;
  border-top: 10px solid;
  border-top-color:  #1d70b8;
  border-bottom: 1px solid;
  border-bottom-color:  #b1b4b6;
  line-height: 1;
}

.md-tabs__link {
  font-size: 18px;
  font-weight: 700;
}

.md-tabs__link:hover {
  text-decoration: underline;
  text-decoration-thickness: 3px;
  text-underline-offset: 3px;
}

.md-tabs__item--active {
  border-bottom: 4px solid;
  border-bottom-color:   #1d70b8;
  /* text-decoration: underline;
  text-decoration-thickness: 3px;
  text-underline-offset: 10px;
  text-decoration-color:   #1d70b8; */
}

.md-typeset .admonition,
.md-typeset details {
  font-size: 16px;
  border: 3px solid;
}
